@@ -50,7 +50,7 @@ class KnowitTree;
 /** Knowit is the base class of the project */
 class Knowit : public TDEMainWindow
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   private:
     static const TQString Untitled;
