@@ -55,8 +55,8 @@ KnowitLinkDialog::KnowitLinkDialog()
    layout->addWidget(new TQLabel(i18n("Link description:"), plainPage()));
    layout->addWidget(linkDescription = new KLineEdit("Link description", plainPage()));
 
-   connect(browse, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotBrowse()));
-   connect(linkType, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotTypeChanged(int)));
+   connect(browse, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotBrowse()));
+   connect(linkType, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotTypeChanged(int)));
 }
 
 KnowitLinkDialog::~KnowitLinkDialog()
@@ -99,3 +99,4 @@ void KnowitLinkDialog::slotTypeChanged(int index)
    browse->setEnabled(!index);
 }
 
+#include "knowitlink.moc"
